@@ -1,6 +1,7 @@
 from .ExceptionHandler import ExceptionHandler
 from .handlers.DumpExceptionHandler import DumpExceptionHandler
 from .handlers.HttpExceptionHandler import HttpExceptionHandler
+from .handlers.ModelNotFoundHandler import ModelNotFoundHandler
 from .DD import DD
 from .exceptions import (
     InvalidRouteCompileException,
@@ -30,4 +31,5 @@ from .exceptions import (
     LoaderNotFound,
     QueueException,
     AmbiguousError,
+    ModelNotFoundException,
 )
