@@ -1,3 +1,4 @@
+from inspect import isclass
 import re
 from urllib import parse
 
@@ -29,6 +30,7 @@ class HTTPRoute:
         self.controllers_locations = controllers_locations
         self.controller = controller
         self.controller_class = None
+        self.controller_instance = None
         self.controller_method = None
         self._domain = None
         self._name = name
@@ -160,8 +162,13 @@ class HTTPRoute:
             except LoaderNotFound as e:
                 self.e = e
                 print("\033[93mTrouble importing controller!", str(e), "\033[0m")
-        # Else it's a controller instance, we don't have to find it, just get the class
-        else:
+        # controller is an instance with a bound method
+        elif hasattr(controller, "__self__"):
+            _, controller_method_str = controller.__qualname__.split(".")
+            self.controller_instance = controller.__self__
+
+        # it's a class or class.method, we don't have to find it, just get the class
+        elif hasattr(controller, "__qualname__"):
             if "." in controller.__qualname__:
                 controller_name, controller_method_str = controller.__qualname__.split(
                     "."
@@ -169,6 +176,7 @@ class HTTPRoute:
             else:
                 controller_name = controller.__qualname__
                 controller_method_str = "__call__"
+
             try:
                 self.controller_class = Loader.get_object(
                     controller.__module__, controller_name, raise_exception=True
@@ -176,6 +184,10 @@ class HTTPRoute:
             except LoaderNotFound as e:
                 self.e = e
                 print("\033[93mTrouble importing controller!", str(e), "\033[0m")
+        # it's a controller instance
+        else:
+            self.controller_instance = controller
+            controller_method_str = "__call__"
 
         # Set the controller method on class. This is a string
         self.controller_method = controller_method_str
@@ -192,14 +204,24 @@ class HTTPRoute:
             raise SyntaxError(str(self.e))
 
         if app:
-            controller = app.resolve(self.controller_class, *self.controller_bindings)
+            if self.controller_instance:
+                controller = self.controller_instance
+            else:
+                controller = app.resolve(
+                    self.controller_class, *self.controller_bindings
+                )
             # resolve route parameters
             params = self.extract_parameters(app.make("request").get_path()).values()
             # Resolve Controller Method
             response = app.resolve(getattr(controller, self.controller_method), *params)
             return response
 
-        return getattr(self.controller_class(), self.controller_method)()
+        if self.controller_instance:
+            controller = self.controller_instance
+        else:
+            controller = self.controller_class()
+
+        return getattr(controller, self.controller_method)()
 
     def middleware(self, *args):
         """Load a list of middleware to run.
