@@ -50,3 +50,11 @@ class TestRequest(TestCase):
         self.assertTrue(request.accepts_json())
         request = self.make_request({"HTTP_ACCEPT": "text/html"})
         self.assertFalse(request.accepts_json())
+
+    def test_getting_request_method(self):
+        request = self.make_request(method="POST")
+        self.assertEqual(request.get_request_method(), "POST")
+
+    def test_overriding_request_method_in_form(self):
+        request = self.make_request(post_data={"__method": "PATCH"}, method="POST")
+        self.assertEqual(request.get_request_method(), "PATCH")
