@@ -1,4 +1,4 @@
-from masonite.environment import env
+from src.masonite.environment import env
 
 
 FROM_EMAIL = env("MAIL_FROM", "no-reply@masonite.com")
@@ -20,4 +20,4 @@ DRIVERS = {
     "terminal": {
         "from": FROM_EMAIL,
     },
-}
\ No newline at end of file
+}
