@@ -17,6 +17,10 @@ DRIVERS = {
         "port": "5672",
         "vhost": "",
         "host": "localhost",
+        # See https://pika.readthedocs.io/en/stable/modules/parameters.html#pika.connection.URLParameters
+        # for valid connection options values
+        "connection_options": {},
+        "exchange": "",
         "channel": "default",
         "queue": "masonite4",
         "tz": "UTC",
