@@ -9,13 +9,15 @@ ROUTES = [
         "play_with_session"
     ),
     Route.post("/", "WelcomeController@show"),
+    Route.get("/contact", "WelcomeController@contact"),
+    Route.post("/contact", "WelcomeController@contact_post"),
     Route.post("/input", "WelcomeController@input"),
     Route.post("/upload", "WelcomeController@upload").name("upload"),
     Route.get("/test", "WelcomeController@test"),
     Route.get("/emit", "WelcomeController@emit"),
     Route.get("/view", "WelcomeController@view"),
     Route.get("/mail", "MailableController@view"),
-    Route.get("/users/@id", "WelcomeController@test").name("users.profile"),
+    Route.get("/users/@id", "WelcomeController@show_user").name("users.profile"),
 ]
 
 Broadcast.routes()
